"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderService = void 0;
const lodash_1 = require("lodash");
const client_1 = require("../services/client");
class OrderService extends client_1.InCartService {
    async createOrder(storeId, order) {
        const { data } = await this.axios.post(`${storeId}/order`, order);
        return data;
    }
    async list(storeId, condition = {}) {
        const { pageSize = 10, currentPage = 1, sortDirection = 'asc', groupBy = '', ...keywords } = condition;
        let requestUrl = `${storeId}/order/search?pageSize=${pageSize}&currentPage=${currentPage}&sortDirection=${sortDirection}`;
        if (!lodash_1.isEmpty(groupBy)) {
            requestUrl = requestUrl.concat(`&groupBy=${groupBy}`);
        }
        const kw = Object.keys(keywords).map((k) => `${k}=${encodeURIComponent(keywords[k])}`).join('&');
        if (!lodash_1.isEmpty(kw)) {
            requestUrl = requestUrl.concat(`&${kw}`);
        }
        const { data } = await this.axios.get(requestUrl);
        return data;
    }
    async getOrderById(storeId, orderId) {
        const { data } = await this.axios.get(`${storeId}/order/${orderId}`);
        return data;
    }
    async updateOrderByid(storeId, orderId, entity) {
        const { data } = await this.axios.post(`${storeId}/order/${orderId}`, entity);
        return data;
    }
}
exports.OrderService = OrderService;
//# sourceMappingURL=orders.js.map