"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InCartAuthAdminService = void 0;
const cerialize_1 = require("cerialize");
const client_1 = require("./client");
const authAdmin_1 = require("./models/authAdmin");
const auth_1 = require("./models/auth");
class InCartAuthAdminService extends client_1.InCartService {
    /**
     *
     * @param overrideAuthenticationToken
     * @return User Admin Profile: { id, name, email }
     */
    async me() {
        const resp = await this.axios.get('/pcms/api/v1/auth/admin/me');
        const r = cerialize_1.Deserialize(resp.data, authAdmin_1.InCartMeResponse);
        // cleanse data
        r.stores = r.stores.filter((o) => o.storeId !== 'global');
        return r;
    }
    /**
     * Initiate Login request with email and password.
     *
     * Example usage:
     *
     * ```ts
     * import { Client, InCartAuthAdminService, getConfiguration } from 'incart-api-client'
     *
     * const client = new Client(getConfiguration('alpha'))
     * const auth = new InCartAuthAdminService(client)
     * const token = await auth.login('test@gmail.com', 'password')
     * client.overrideSession(token)
     * const me = await auth.me()
     * ```
     *
     * @param email
     * @param password
     * @returns AccessToken
     */
    async login(email, password) {
        const resp = await this.axios.post('/pcms/api/v1/auth/admin/access-tokens', {
            email,
            password,
        }, {
            headers: {
                'x-api-key': '',
            }
        });
        const r = cerialize_1.Deserialize(resp.data, auth_1.InCartAccessTokenResponse);
        return r;
    }
}
exports.InCartAuthAdminService = InCartAuthAdminService;
//# sourceMappingURL=authAdmin.js.map