"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InCartService = exports.Client = exports.isInCartEnv = void 0;
const axios_1 = __importDefault(require("axios"));
const get_1 = __importDefault(require("lodash/get"));
const isInCartEnv = (o) => {
    return /^(alpha|qa|prod|A|Q|P)$/.test(o);
};
exports.isInCartEnv = isInCartEnv;
class Client {
    constructor(config, logger, logOption) {
        this.config = config;
        this.logger = logger;
        this._axios = axios_1.default.create({
            baseURL: config.baseURL,
        });
        this._axios.interceptors.request.use((conf) => {
            if (this._token) {
                conf.headers = {
                    'authorization': this._token.accessToken,
                    'x-api-key': '',
                };
            }
            else {
                conf.headers = {
                    'x-api-key': config.apiKey
                };
            }
            this.logger?.log(`${logOption?.requestPrefix || 'REQ >'} ${conf.url}`, conf);
            return conf;
        });
        this._axios.interceptors.response.use((resp) => {
            this.logger?.log(`${logOption?.responsePrefix || 'RESP <'} ${resp.config.url}`, resp.data);
            return resp;
        }, (error) => {
            this.logger?.log('INCART SERVICE FAILED.');
            this.logger?.log(`${logOption?.errorPrefix || '.. ER <'} < message ${error.message}`);
            if (error.response) {
                const message = get_1.default(error.response, 'data.info.message', get_1.default(error.response, 'data.message', error.message));
                this.logger?.log(`${logOption?.errorPrefix || '.. ER <'} < detail ${JSON.stringify(error.response?.data)}`);
                throw new Error(message);
            }
            throw error;
        });
    }
    static getInstance(config) {
        const key = `${config.baseURL}@${config.apiKey}`;
        return this._instances[key] || (this._instances[key] = new Client(config));
    }
    get axios() { return this._axios; }
    overrideSession(token) {
        this._token = token;
    }
}
exports.Client = Client;
Client._instances = {};
class InCartService {
    constructor(client) {
        this.client = client;
    }
    // Short-hand
    get axios() {
        return this.client.axios;
    }
}
exports.InCartService = InCartService;
//# sourceMappingURL=client.js.map