"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InCartProductsService = exports.simpleInCartProductFields = void 0;
const pick_1 = __importDefault(require("lodash/pick"));
const luxon_1 = require("luxon");
const cerialize_1 = require("cerialize");
const client_1 = require("./client");
const products_1 = require("./models/products");
exports.simpleInCartProductFields = ['id', 'sku', 'name', 'price', 'brand', 'categories', 'children', 'description', 'media'];
class InCartProductsService extends client_1.InCartService {
    async list(storeId, queryOpt = {}) {
        const pick = queryOpt.pick && queryOpt.pick.length > 0 ? queryOpt.pick.join(',') : undefined;
        const params = {
            lang: 'th',
            pageSize: `${queryOpt.pageSize || 24}`,
            currentPage: `${queryOpt.currentPage || 1}`,
            visibility: `${queryOpt.visibility || 'public'}`,
            checkStock: `${queryOpt.checkStock || 'false'}`,
            checkStatus: `${queryOpt.checkStatus || 'false'}`,
            sku: queryOpt.sku && queryOpt.sku,
            priceFrom: queryOpt.priceFrom,
            priceTo: queryOpt.priceTo,
            pick,
        };
        const res = await this.axios.get(`/pcms/${storeId}/api/v1/products`, { params });
        return res.data;
    }
    async listBySku(storeId, skus, fieldOpt) {
        const params = {
            skus: `[${skus.join(',')}]`,
        };
        const res = await this.axios.get(`/pcms/${storeId}/api/v1/products/multiple/skus`, { params });
        const collection = res.data.collection.map((o) => pick_1.default(o, ...fieldOpt.pick));
        return collection;
    }
    async getBySku(storeId, sku) {
        const res = await this.axios.get(`/pcms/${storeId}/api/v1/products/${sku}`);
        return res.data;
    }
    async getMasterProductsForSync(storeId, opts) {
        const params = {
            limit: opts.limit,
            offset: opts.offset,
            sortBy: opts.sortBy,
            sortDirection: opts.sortDirection,
            keyword: opts.keyword,
            traceId: opts.traceId || `${Math.random() * 99999}`,
        };
        if (opts.lastUpdate) {
            const dt = luxon_1.DateTime.fromJSDate(opts.lastUpdate);
            if (!dt.isValid) {
                throw new Error(`Cannot sync with invalidate date value: ${opts.lastUpdate}`);
            }
            params.lastSyncTimestamp = dt.setZone('UTC').toISO();
        }
        try {
            const res = await this.axios.get(`/pcms/${storeId}/api/v1/products/master`, { params });
            return cerialize_1.Deserialize(res.data.collection, products_1.MultipleLangInCartProduct);
        }
        catch (error) {
            this.client.logger?.log('WARNING: Unable to fetch master products from inCart', error);
            throw error;
        }
    }
}
exports.InCartProductsService = InCartProductsService;
//# sourceMappingURL=products.js.map