"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InCartStoreService = void 0;
const cerialize_1 = require("cerialize");
const client_1 = require("./client");
const store_1 = require("./models/store");
class InCartStoreService extends client_1.InCartService {
    /**
     * @param overrideAuthenticationToken
     * @return User Admin Profile: { id, name, email }
     */
    async getStore(storeId) {
        const resp = await this.axios.get(`/pcms/api/v1/stores/${storeId}/settings/general`);
        return cerialize_1.DeserializeInto(resp.data, store_1.InCartStore, new store_1.InCartStore(storeId));
    }
    async getLocation(storeId) {
        const resp = await this.axios.get(`/${storeId}/api/v1/custom-domains/location`);
        return cerialize_1.DeserializeInto(resp.data, store_1.InCartLocation, new store_1.InCartLocation(storeId));
    }
    async getPackage(storeId) {
        const resp = await this.axios.get(`/${storeId}/api/v1/subscriptions/package`);
        return cerialize_1.Deserialize(resp.data, store_1.InCartStorePackage);
    }
    /**
     * Validate if given store name exists?
     *
     * @param storeIdCandidate
     * @returns Status of candiate, or a new name if given store already exists.
     */
    async validate(storeIdCandidate) {
        const resp = await this.axios.post(`/pcms/api/v1/stores/validate`, {
            storeName: storeIdCandidate
        });
        return cerialize_1.Deserialize(resp.data, store_1.InCartStoreNameCandidateValidation);
    }
}
exports.InCartStoreService = InCartStoreService;
//# sourceMappingURL=store.js.map