"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DateSerializer = exports.FractionSerializer = exports.JsonObjectToArraySerializer = exports.ISODateSerializer = exports.BooleanSerializer = void 0;
const cerialize_1 = require("cerialize");
const fraction_js_1 = __importDefault(require("fraction.js"));
const BooleanSerializer = (trueValue, falseValue) => ({
    Serialize(jsValue) {
        return jsValue ? trueValue : falseValue;
    },
    Deserialize(jsonValue) {
        return jsonValue === trueValue;
    }
});
exports.BooleanSerializer = BooleanSerializer;
exports.ISODateSerializer = ({
    Serialize(jsValue) {
        return jsValue.toISOString();
    },
    Deserialize(jsonValue) {
        return new Date(jsonValue);
    }
});
const JsonObjectToArraySerializer = (cnstr, serializeKey) => ({
    Serialize(jsValue) {
        if (!jsValue) {
            return {};
        }
        const r = {};
        for (const o of jsValue) {
            const key = serializeKey(o);
            r[key] = cerialize_1.Serialize(o, cnstr);
        }
        return r;
    },
    Deserialize(jsonValue) {
        const r = [];
        for (const k in jsonValue) {
            const e = cerialize_1.DeserializeInto(jsonValue[k], cnstr, new cnstr(k));
            r.push(e);
        }
        return r;
    }
});
exports.JsonObjectToArraySerializer = JsonObjectToArraySerializer;
exports.FractionSerializer = {
    Serialize(value) {
        if (typeof value === 'number') {
            return value;
        }
        if (typeof value === 'undefined') {
            return undefined;
        }
        if (value === null) {
            return null;
        }
        if (value instanceof fraction_js_1.default) {
            return value.toString();
        }
        return +value;
    },
    Deserialize(value) {
        if (typeof value === 'undefined') {
            return undefined;
        }
        else if (value === null) {
            return null;
        }
        else if (typeof value === 'string') {
            return new fraction_js_1.default(value.trim() || 0);
        }
        return new fraction_js_1.default(value);
    }
};
exports.DateSerializer = {
    /**
     * dataValue => JSON data
     * @param dataValue
     * @returns number
     */
    Serialize(json) {
        if (!json) {
            return null;
        }
        if (typeof json === 'string') {
            // Compare with Regex.
            return new Date(json).getTime();
        }
        if (json instanceof Date) {
            return json.getTime();
        }
        return null;
    },
    Deserialize(json) {
        if (!json) {
            return null;
        }
        if (typeof json === 'number' || typeof json === 'string') {
            // Compare with Regex.
            return new Date(json);
        }
        if (json instanceof Date) {
            return json;
        }
        return null;
    }
};
//# sourceMappingURL=cerialize.js.map