import axios from 'axios';
import get from 'lodash/get';
export const isInCartEnv = (o) => {
    return /^(alpha|qa|prod|A|Q|P)$/.test(o);
};
export class Client {
    constructor(config, logger, logOption) {
        this.config = config;
        this.logger = logger;
        this._axios = axios.create({
            baseURL: config.baseURL,
        });
        this._axios.interceptors.request.use((conf) => {
            if (this._token) {
                conf.headers = {
                    'authorization': this._token.accessToken,
                    'x-api-key': '',
                };
            }
            else {
                conf.headers = {
                    'x-api-key': config.apiKey
                };
            }
            this.logger?.log(`${logOption?.requestPrefix || 'REQ >'} ${conf.url}`, conf);
            return conf;
        });
        this._axios.interceptors.response.use((resp) => {
            this.logger?.log(`${logOption?.responsePrefix || 'RESP <'} ${resp.config.url}`, resp.data);
            return resp;
        }, (error) => {
            this.logger?.log('INCART SERVICE FAILED.');
            this.logger?.log(`${logOption?.errorPrefix || '.. ER <'} < message ${error.message}`);
            if (error.response) {
                const message = get(error.response, 'data.info.message', get(error.response, 'data.message', error.message));
                this.logger?.log(`${logOption?.errorPrefix || '.. ER <'} < detail ${JSON.stringify(error.response?.data)}`);
                throw new Error(message);
            }
            throw error;
        });
    }
    static getInstance(config) {
        const key = `${config.baseURL}@${config.apiKey}`;
        return this._instances[key] || (this._instances[key] = new Client(config));
    }
    get axios() { return this._axios; }
    overrideSession(token) {
        this._token = token;
    }
}
Client._instances = {};
export class InCartService {
    constructor(client) {
        this.client = client;
    }
    // Short-hand
    get axios() {
        return this.client.axios;
    }
}
//# sourceMappingURL=client.js.map