import { LangPair } from "./base";
export declare class MinMaxValue {
    min: number | null;
    max: number | null;
    static zero(): MinMaxValue;
}
export declare class PriceFormat {
    original: MinMaxValue;
    special: MinMaxValue | null;
    static noNull(value?: PriceFormat): PriceFormat;
}
export declare class Suggest {
    input: string[];
    contexts: {};
}
export declare class LangsSuggest {
    en: Suggest;
    th: Suggest;
}
export declare class WareHouse {
    id: number;
    name: string;
    active: boolean;
    created_at: string;
    updated_at: string;
}
export declare class Inventory {
    qty: number | null;
    stockType: string;
}
export declare class Warehouse {
    id: number;
    name: string;
    active: boolean;
    created_at: string;
    updated_at: string | null;
}
export declare class ChannelWarehouses {
    id: number;
    channelId: number;
    warehouseId: number;
    warehouse_id: number;
    warehouse: Warehouse;
}
export declare class Channel {
    id: number;
    type: string | null;
    name: string | null;
    updatedAt: Date | null;
    createdAt: Date;
    channel_warehouses: ChannelWarehouses[] | null;
}
export declare class ProductRef {
    id: number;
    productId: number;
    channelId: number;
    name: string | null;
    itemId: number | null;
    variantId: number | null;
    price: number | null;
    specialPrice: number | null;
    refType: string | null;
    channel_id: number;
    channel: Channel;
}
export declare class Stock {
    sku?: string;
    indexId?: string;
    qty: number | null;
    productId?: string | null;
    stockType: 'infinite' | 'normal';
    warehouseId?: number | null;
    refillThresholdValue?: number;
    updatedAt?: Date;
}
export declare class Media {
    id: number;
    path: string | null;
    type: string;
    ref: string;
    position: number;
}
export declare class StockReserve {
    orderId: string;
    qty: number;
}
declare class BaseTaxonomy {
    id: number;
}
export declare class LocalizedTaxonomy extends BaseTaxonomy {
    label: string;
}
export declare class LangTaxonomy extends BaseTaxonomy {
    label: LangPair;
}
export declare class Brand {
    id: number;
    label: LangPair | null;
    actualValue: number | null;
}
export declare class Badge {
    id: number;
    label: string;
    actualValue: number | null;
}
export declare class SubOptions {
    id: number;
    label: LangPair;
    actualValue: number | null;
}
export declare class BaseOptions {
    attributeId: number;
    type: string;
    code: string;
    label: LangPair;
    options: SubOptions[];
}
export declare class LocalizedOptions {
    label: string;
}
export declare class LangOptions extends BaseOptions {
    label: LangPair;
}
export declare class Attributes {
    options: BaseOptions[] | null;
}
export declare class PaymentMethods {
    id: number;
    isBrandActive: boolean;
}
export declare class ToPage {
    pageId: string;
    labelTh: string | null;
    labelEn: string | null;
    sortOrder: number;
}
declare class BaseInCartProduct {
    id: number;
    sku: string;
    storeId: string;
    type: 'simple' | 'configurable';
    width: number | null;
    height: number | null;
    length: number | null;
    weight: number | null;
    visibility: 'public' | 'private' | 'all';
    status: boolean;
    createdAt: Date;
    updatedAt: Date | null;
    price: PriceFormat;
    stock: Stock;
    inventory: Inventory[] | null;
    media: Media[] | null;
    refillThresholdValue: number | null;
    brand: Brand | null;
    badge: Badge | null;
    properties: Array<any>;
    attributes: Attributes | null;
    constructor(from?: BaseInCartProduct | null);
}
export declare class InCartProduct extends BaseInCartProduct {
    name: string;
    description: string;
    categories: LocalizedTaxonomy[] | null;
    tags: LangTaxonomy[] | null;
    children: InCartProduct[] | null;
    constructor(from?: InCartProduct | null);
}
export declare class MultipleLangInCartProduct extends BaseInCartProduct {
    byStoreId?: number;
    name: LangPair;
    title: LangPair;
    description: LangPair | null;
    categories: LangTaxonomy[] | null;
    tags: LangTaxonomy[] | null;
    codeColor?: string | null;
    colorSwatch?: string | null;
    children: MultipleLangInCartProduct[];
    stockReserve: StockReserve[] | null;
    vizCoin?: number;
    rawQty?: number | null;
    refillStock?: boolean | null;
    backInStockTimeStamp: number;
    constructor(from?: MultipleLangInCartProduct | null);
}
export declare class Payloads {
    stocks: Stock[];
    refillThresholdValue?: number;
    updatedAt: Date;
}
export declare class PayloadStock {
    payloads: Payloads[];
    storeId: string;
}
export declare class Products {
    id: number;
    sku: string;
    stockType: 'infinite' | 'normal';
    qty: number;
    type: 'simple' | 'configurable';
}
export declare class PayloadUpdateStockIncart {
    products: Products[];
    storeId: string;
}
export declare class ReserveStock {
    sku: string;
    storeId: string;
    orderId: string;
    qty: number;
    indexId?: string;
    returnStock?: boolean | true;
}
export declare class PayloadReserveStock {
    payloads: ReserveStock[];
}
export {};
