import { InCartService } from './client';
export class InCartOrdersService extends InCartService {
    async updateOrderComment(storeId, orderId, comment, source, entityName) {
        return this.axios.post(`/pcms/${storeId}/api/v1/orders/${orderId}/comments`, {
            isCustomerNotified: 0,
            comment,
            source,
            entityName,
        });
    }
    async updateOrderStatus(storeId, orderId, status) {
        return this.axios.put(`/pcms/${storeId}/api/v1/orders/${orderId}/statuses`, {
            status
        });
    }
    async updateOrderShipment(storeId, orderId, trackingNumber) {
        const tracking = trackingNumber !== '' && { track: { trackNumber: trackingNumber } };
        return this.axios.post(`/pcms/${storeId}/api/v1/shipments`, {
            orderId,
            ...tracking
        });
    }
    async cancelOrder(storeId, orderId) {
        return this.axios.post(`/pcms/${storeId}/api/v1/orders/${orderId}/cancel`);
    }
    /**
     * Request estimate shipping cost along with available shipping options
     *
     * @param storeId
     * @param orderId
     */
    async estimateShippingCost(storeId, orderId) {
        const r = await this.axios.get(`/pcms/${storeId}/api/v1/orders/${orderId}/estimate-shipping`);
        return r.data;
    }
    async updateShippingMethod(storeId, orderId, shippingMethodId) {
        await this.axios.put(`/pcms/${storeId}/api/v1/orders/${orderId}/shipping-methods`, { shippingMethodId });
    }
    async updateEmailOrMobile(storeId, orderId, emailOrMobile) {
        const req = {
            email: emailOrMobile,
        };
        const r = await this.axios.put(`/pcms/${storeId}/api/v1/orders/${orderId}/emails`, req);
        const data = r.data;
        return data.status;
    }
    async updateAddress(storeId, orderId, addressType, updateAddressRequest) {
        switch (addressType) {
            case 'billing': return this.updateBillingAddress(storeId, orderId, updateAddressRequest);
            case 'shipping': return this.updateShippingAddress(storeId, orderId, updateAddressRequest);
        }
    }
    /**
     * Unset billing address - mimic what Dashboard has updated.
     *
     * @param storeId
     * @param orderId
     * @return
     */
    async removeBillingAddress(storeId, orderId) {
        return this.updateBillingAddress(storeId, orderId, {
            country: null,
            district: null,
            subDistrict: null,
            mobile: { number: null, countryCode: null },
            province: null,
            firstname: null,
            vatId: null,
            street: null,
        });
    }
    async updateShippingAddress(storeId, orderId, updateAddressRequest) {
        const r = await this.axios.put(`/pcms/${storeId}/api/v1/orders/${orderId}/shipping-addresses`, updateAddressRequest);
        const data = r.data;
        return data.status;
    }
    async updateBillingAddress(storeId, orderId, updateAddressRequest) {
        const r = await this.axios.put(`/pcms/${storeId}/api/v1/orders/${orderId}/billing-addresses`, updateAddressRequest);
        const data = r.data;
        return data.status;
    }
    async listPaymentMethods(storeId, orderId) {
        const r = await this.axios.get(`/pcms/${storeId}/api/v1/orders/${orderId}/payment-methods`);
        return r.data;
    }
    async updatePaymentMethod(storeId, orderId, paymentMethodId) {
        await this.axios.put(`/pcms/${storeId}/api/v1/orders/${orderId}/payment-methods`, { paymentMethodId });
    }
    async listOrders(storeId, params) {
        const r = await this.axios.get(`/pcms/${storeId}/api/v1/orders`, { params });
        return r.data;
    }
    async listOrderDetail(storeId, orderId) {
        const r = await this.axios.get(`/pcms/${storeId}/api/v1/orders/${orderId}`);
        return r.data;
    }
}
//# sourceMappingURL=orders.js.map