import pick from 'lodash/pick';
import { DateTime } from 'luxon';
import { Deserialize } from 'cerialize';
import { InCartService } from './client';
import { MultipleLangInCartProduct } from './models/products';
export const simpleInCartProductFields = ['id', 'sku', 'name', 'price', 'brand', 'categories', 'children', 'description', 'media'];
export class InCartProductsService extends InCartService {
    async list(storeId, queryOpt = {}) {
        const pick = queryOpt.pick && queryOpt.pick.length > 0 ? queryOpt.pick.join(',') : undefined;
        const params = {
            lang: 'th',
            pageSize: `${queryOpt.pageSize || 24}`,
            currentPage: `${queryOpt.currentPage || 1}`,
            visibility: `${queryOpt.visibility || 'public'}`,
            checkStock: `${queryOpt.checkStock || 'false'}`,
            checkStatus: `${queryOpt.checkStatus || 'false'}`,
            sku: queryOpt.sku && queryOpt.sku,
            priceFrom: queryOpt.priceFrom,
            priceTo: queryOpt.priceTo,
            pick,
        };
        const res = await this.axios.get(`/pcms/${storeId}/api/v1/products`, { params });
        return res.data;
    }
    async listBySku(storeId, skus, fieldOpt) {
        const params = {
            skus: `[${skus.join(',')}]`,
        };
        const res = await this.axios.get(`/pcms/${storeId}/api/v1/products/multiple/skus`, { params });
        const collection = res.data.collection.map((o) => pick(o, ...fieldOpt.pick));
        return collection;
    }
    async getBySku(storeId, sku) {
        const res = await this.axios.get(`/pcms/${storeId}/api/v1/products/${sku}`);
        return res.data;
    }
    async getMasterProductsForSync(storeId, opts) {
        const params = {
            limit: opts.limit,
            offset: opts.offset,
            sortBy: opts.sortBy,
            sortDirection: opts.sortDirection,
            keyword: opts.keyword,
            traceId: opts.traceId || `${Math.random() * 99999}`,
        };
        if (opts.lastUpdate) {
            const dt = DateTime.fromJSDate(opts.lastUpdate);
            if (!dt.isValid) {
                throw new Error(`Cannot sync with invalidate date value: ${opts.lastUpdate}`);
            }
            params.lastSyncTimestamp = dt.setZone('UTC').toISO();
        }
        try {
            const res = await this.axios.get(`/pcms/${storeId}/api/v1/products/master`, { params });
            return Deserialize(res.data.collection, MultipleLangInCartProduct);
        }
        catch (error) {
            this.client.logger?.log('WARNING: Unable to fetch master products from inCart', error);
            throw error;
        }
    }
}
//# sourceMappingURL=products.js.map