import { Deserialize, DeserializeInto } from 'cerialize';
import { InCartService } from './client';
import { InCartLocation, InCartStore, InCartStoreNameCandidateValidation, InCartStorePackage } from './models/store';
export class InCartStoreService extends InCartService {
    /**
     * @param overrideAuthenticationToken
     * @return User Admin Profile: { id, name, email }
     */
    async getStore(storeId) {
        const resp = await this.axios.get(`/pcms/api/v1/stores/${storeId}/settings/general`);
        return DeserializeInto(resp.data, InCartStore, new InCartStore(storeId));
    }
    async getLocation(storeId) {
        const resp = await this.axios.get(`/${storeId}/api/v1/custom-domains/location`);
        return DeserializeInto(resp.data, InCartLocation, new InCartLocation(storeId));
    }
    async getPackage(storeId) {
        const resp = await this.axios.get(`/${storeId}/api/v1/subscriptions/package`);
        return Deserialize(resp.data, InCartStorePackage);
    }
    /**
     * Validate if given store name exists?
     *
     * @param storeIdCandidate
     * @returns Status of candiate, or a new name if given store already exists.
     */
    async validate(storeIdCandidate) {
        const resp = await this.axios.post(`/pcms/api/v1/stores/validate`, {
            storeName: storeIdCandidate
        });
        return Deserialize(resp.data, InCartStoreNameCandidateValidation);
    }
}
//# sourceMappingURL=store.js.map